==> gnome-dvb-daemon-0.1.3.tar.gz: gnome-dvb-daemon-0.1.3/src/EPGScanner.h <==

#ifndef __SRC_EPGSCANNER_H__
#define __SRC_EPGSCANNER_H__

#include <glib.h>
#include <glib-object.h>
#include <gst/gst.h>
#include "src/DeviceGroup.h"

G_BEGIN_DECLS


#define DVB_TYPE_EPG_SCANNER (dvb_epg_scanner_get_type ())
#define DVB_EPG_SCANNER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_EPG_SCANNER, DVBEPGScanner))
#define DVB_EPG_SCANNER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_EPG_SCANNER, DVBEPGScannerClass))
#define DVB_IS_EPG_SCANNER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_EPG_SCANNER))
#define DVB_IS_EPG_SCANNER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_EPG_SCANNER))
#define DVB_EPG_SCANNER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_EPG_SCANNER, DVBEPGScannerClass))

typedef struct _DVBEPGScanner DVBEPGScanner;
typedef struct _DVBEPGScannerClass DVBEPGScannerClass;
typedef struct _DVBEPGScannerPrivate DVBEPGScannerPrivate;

struct _DVBEPGScanner {
	GObject parent_instance;
	DVBEPGScannerPrivate * priv;
};

struct _DVBEPGScannerClass {
	GObjectClass parent_class;
};


DVBEPGScanner* dvb_epg_scanner_construct (GType object_type, DVBDeviceGroup* device);
DVBEPGScanner* dvb_epg_scanner_new (DVBDeviceGroup* device);
void dvb_epg_scanner_stop (DVBEPGScanner* self);
gboolean dvb_epg_scanner_start (DVBEPGScanner* self);
void dvb_epg_scanner_on_eit_structure (DVBEPGScanner* self, const GstStructure* structure);
DVBDeviceGroup* dvb_epg_scanner_get_DeviceGroup (DVBEPGScanner* self);
void dvb_epg_scanner_set_DeviceGroup (DVBEPGScanner* self, DVBDeviceGroup* value);
GType dvb_epg_scanner_get_type (void);


G_END_DECLS

#endif

==> gnome-dvb-daemon-0.1.4.tar.gz: gnome-dvb-daemon-0.1.4/src/EPGScanner.h <==

#ifndef __SRC_EPGSCANNER_H__
#define __SRC_EPGSCANNER_H__

#include <glib.h>
#include <glib-object.h>
#include <gst/gst.h>
#include "src/DeviceGroup.h"

G_BEGIN_DECLS


#define DVB_TYPE_EPG_SCANNER (dvb_epg_scanner_get_type ())
#define DVB_EPG_SCANNER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DVB_TYPE_EPG_SCANNER, DVBEPGScanner))
#define DVB_EPG_SCANNER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DVB_TYPE_EPG_SCANNER, DVBEPGScannerClass))
#define DVB_IS_EPG_SCANNER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DVB_TYPE_EPG_SCANNER))
#define DVB_IS_EPG_SCANNER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DVB_TYPE_EPG_SCANNER))
#define DVB_EPG_SCANNER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DVB_TYPE_EPG_SCANNER, DVBEPGScannerClass))

typedef struct _DVBEPGScannerPrivate DVBEPGScannerPrivate;

struct _DVBEPGScanner {
	GObject parent_instance;
	DVBEPGScannerPrivate * priv;
};

struct _DVBEPGScannerClass {
	GObjectClass parent_class;
};


DVBEPGScanner* dvb_epg_scanner_construct (GType object_type, DVBDeviceGroup* device);
DVBEPGScanner* dvb_epg_scanner_new (DVBDeviceGroup* device);
void dvb_epg_scanner_stop (DVBEPGScanner* self);
void dvb_epg_scanner_destroy (DVBEPGScanner* self);
gboolean dvb_epg_scanner_start (DVBEPGScanner* self);
void dvb_epg_scanner_on_eit_structure (DVBEPGScanner* self, const GstStructure* structure);
DVBDeviceGroup* dvb_epg_scanner_get_DeviceGroup (DVBEPGScanner* self);
void dvb_epg_scanner_set_DeviceGroup (DVBEPGScanner* self, DVBDeviceGroup* value);
GType dvb_epg_scanner_get_type (void);


G_END_DECLS

#endif
